<?php

namespace Drupal\drupal_planet_feeds_block\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Provides a 'DrupalPlanetFeedsBlock' block.
 *
 * @Block(
 *  id = "drupal_planet_feeds_block",
 *  admin_label = @Translation("Planet Drupal"),
 * )
 */
class DrupalPlanetFeedsBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form['number_of_feeds_to_display'] = array(
      '#type' => 'number',
      '#title' => $this->t('Number of feeds to display'),
      '#description' => $this->t('Enter the number of planets feeds to be displayed.'),
      '#default_value' => isset($this->configuration['number_of_feeds_to_display']) ? $this->configuration['number_of_feeds_to_display'] : '',
      '#min' => 1,
      '#max' => 30,
    );

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $this->configuration['number_of_feeds_to_display'] = $form_state->getValue('number_of_feeds_to_display');
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $build = [];

    $number = $this->configuration['number_of_feeds_to_display'];
    if (isset($number)) {
      $xml = simplexml_load_file('https://www.drupal.org/planet/rss.xml');
      $i = 0;
      foreach ($xml->channel->item as $entry) {
        $i = $i + 1;
        if ($i > $number) {
          continue;
        }
        $entry_array = (array) $entry;
        $url = Url::fromUri($entry_array['link']);
        $link = \Drupal::l($entry_array['title'], $url);
        $build['drupal_planet_feed' . $i] = [
          '#type' => 'markup',
          '#markup' => '<h4>' . $link->getGeneratedLink() . '</h4>',
        ];
      }
    }

    $build['#cache']['max-age'] = 0;
    return $build;
  }

}
